Run the pixel function on a chunk of data.
over_block_draw(chunk, parameters, pr_to_ar_dt, confidence_percent)
| chunk | a list with the pfpr and am datasets. |
|---|---|
| parameters | a data.frame, at this point, with a row per draw. |
| pr_to_ar_dt | The pr2ar mesh data. |
| confidence_percent | Confidence interval, out of 100. |